@@ -53,9 +53,10 @@ Example:
 """
 
 from __future__ import unicode_literals
-import pexpect, sys, time
+import pexpect, sys, time, subprocess
 import byexample.regex as re
 from byexample.common import constant
+from byexample.log import clog
 from byexample.parser import ExampleParser
 from byexample.finder import ExampleFinder
 from byexample.runner import ExampleRunner, PexpectMixin, ShebangTemplate
@@ -123,6 +124,12 @@ class RubyParser(ExampleParser):
                             help='print the expression\'s value (true); ' +\
                                  'suppress it (false); or print it only ' +\
                                  'if the example has a => (auto, the default)')
+        parser.add_flag(
+            "ruby-start-large-output-in-new-line",
+            default=False,
+            help="add a newline after the => if the output that follows " +\
+                 "does not fit in a single line. (irb >= 1.2.2)"
+        )
         return parser
 
 
@@ -168,23 +175,74 @@ class RubyInterpreter(ExampleRunner, PexpectMixin):
     def interact(self, example, options):
         PexpectMixin.interact(self)
 
-    def get_default_cmd(self, *args, **kargs):
+    def get_default_cmd(self, version, *args, **kargs):
+        if version and version >= (1, 2, 0):
+            args = ['-f', '--nomultiline', '--nocolorize', '--noreadline']
+        else:
+            args = ['--noreadline']
+
+        return "%e %p %a", {'e': '/usr/bin/env', 'p': 'irb', 'a': args}
+
+    def get_default_version_cmd(self, *args, **kargs):
         return "%e %p %a", {
             'e': '/usr/bin/env',
             'p': 'irb',
-            'a': ['--noreadline']
+            'a': ['--version']
         }
 
+    def build_cmd(self, options, default_shebang, default_tokens, joined=True):
+        shebang, tokens = default_shebang, default_tokens
+        shebang = options['shebangs'].get(self.language, shebang)
+
+        return ShebangTemplate(shebang).quote_and_substitute(tokens, joined)
+
+    @constant
+    def version_regex(self):
+        return re.compile(
+            r'''
+                ([^\d]|^)
+                (?P<major>\d+)
+                \.
+                (?P<minor>\d+)
+                (\. (?P<patch>\d+))?
+                ([^\d]|$)
+                ''', re.VERBOSE
+        )
+
+    @constant
+    def get_version(self, options):
+        cmd = self.build_cmd(
+            options, *self.get_default_version_cmd(), joined=False
+        )
+        try:
+            out = subprocess.check_output(cmd).decode(self.encoding)
+            m = self.version_regex().search(out)
+
+            version = (
+                int(m.group(k) or 0) for k in ("major", "minor", "patch")
+            )
+            version = tuple(version)
+
+        except Exception as err:
+            clog().info(
+                "Could not detect interpreter version: %s\nExecuted command: %s",
+                str(err), cmd
+            )
+            return None
+
+        return version
+
     def initialize(self, options):
         ruby_pretty_print = options['ruby_pretty_print']
 
-        # always/yes; never/no; autoetect normalization
+        # always/yes; never/no; autodetect normalization
         self.expr_print_mode = options['ruby_expr_print']
 
-        shebang, tokens = self.get_default_cmd()
-        shebang = options['shebangs'].get(self.language, shebang)
+        newline_before_multiline_output = options[
+            'ruby_start_large_output_in_new_line']
 
-        cmd = ShebangTemplate(shebang).quote_and_substitute(tokens)
+        version = self.get_version(options)
+        cmd = self.build_cmd(options, *self.get_default_cmd(version))
 
         dfl_timeout = options['x']['dfl_timeout']
 
@@ -194,8 +252,13 @@ class RubyInterpreter(ExampleRunner, PexpectMixin):
         # In RVM contexts the IRB's prompt mode is changed even
         # if we force the mode from the command line (whe we spawn IRB)
         # Make sure that the first thing executed restores the default prompt.
+        #
+        # Also, set if IRB should print or not a newline between the => marker
+        # and the output if it is larger than a single line
+        nl = "true" if newline_before_multiline_output else "false"
         self._exec_and_wait(
-            'IRB.CurrentContext.prompt_mode = :DEFAULT\n',
+            'IRB.CurrentContext.prompt_mode = :DEFAULT\n' +
+            'IRB.CurrentContext.newline_before_multiline_output = %s\n' % nl,
             options,
             timeout=dfl_timeout
         )
